@@ -3,8 +3,7 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef EDITORUTILTEST_H
-#define EDITORUTILTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -13,7 +12,7 @@ class EditorUtilTest : public QObject
     Q_OBJECT
 public:
     explicit EditorUtilTest(QObject *parent = nullptr);
-    ~EditorUtilTest();
+    ~EditorUtilTest() override;
 private Q_SLOTS:
     void testUpperCase();
     void testUpperCase_data();
@@ -25,4 +24,3 @@ private Q_SLOTS:
     void testReverseCase_data();
 };
 
-#endif // EDITORUTILTEST_H
