@@ -1,31 +1,18 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDITRICHTEXTCOMPOSER_H
-#define KPIMTEXTEDITRICHTEXTCOMPOSER_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 
 #include <kpimtextedit/richtexteditor.h>
 class KActionCollection;
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextComposerControler;
 class RichTextComposerActions;
 class RichTextExternalComposer;
@@ -42,8 +29,8 @@ public:
     ~RichTextComposer() override;
 
     enum Mode {
-        Plain,    ///< Plain text mode
-        Rich      ///< Rich text mode
+        Plain, ///< Plain text mode
+        Rich ///< Rich text mode
     };
 
     /**
@@ -91,8 +78,8 @@ public:
     Q_REQUIRED_RESULT bool checkExternalEditorFinished();
     void killExternalEditor();
 
-    //Redefine it for each apps
-    virtual QString smartQuote(const QString &msg);    //need by kmail
+    // Redefine it for each apps
+    virtual QString smartQuote(const QString &msg); // need by kmail
 
     void setQuotePrefixName(const QString &quotePrefix);
     Q_REQUIRED_RESULT QString quotePrefixName() const;
@@ -149,7 +136,6 @@ private:
     void evaluateListSupport(QKeyEvent *event);
     void evaluateReturnKeySupport(QKeyEvent *event);
     class RichTextComposerPrivate;
-    RichTextComposerPrivate *const d;
+    std::unique_ptr<RichTextComposerPrivate> const d;
 };
 }
-#endif // RICHTEXTCOMPOSER_H
