@@ -4,12 +4,11 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDITRICHTEXTCOMPOSEREMAILQUOTEDECORATOR_H
-#define KPIMTEXTEDITRICHTEXTCOMPOSEREMAILQUOTEDECORATOR_H
+#pragma once
 
 #include "kpimtextedit_export.h"
+#include <memory>
 #include <sonnet/spellcheckdecorator.h>
-
 namespace KPIMTextEdit
 {
 class RichTextComposer;
@@ -29,8 +28,7 @@ protected:
 
 private:
     class RichTextComposerEmailQuoteDecoratorPrivate;
-    RichTextComposerEmailQuoteDecoratorPrivate *const d;
+    std::unique_ptr<RichTextComposerEmailQuoteDecoratorPrivate> const d;
 };
 }
 
-#endif // RICHTEXTCOMPOSEREMAILQUOTEDECORATOR_H
