@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include <KActionCollection>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 #include <QToolBar>
-#include <KActionCollection>
 
 #include <../richtextcomposer.h>
 
@@ -23,10 +23,10 @@ int main(int argc, char **argv)
     parser.addVersionOption();
     parser.addHelpOption();
     parser.process(app);
-    auto *richtextcomposerwidget = new KPIMTextEdit::RichTextComposer;
+    auto richtextcomposerwidget = new KPIMTextEdit::RichTextComposer;
     KActionCollection *ac = new KActionCollection(richtextcomposerwidget);
     richtextcomposerwidget->createActions(ac);
-    auto *editor = new KPIMTextEdit::RichTextEditorWidget(richtextcomposerwidget);
+    auto editor = new KPIMTextEdit::RichTextEditorWidget(richtextcomposerwidget);
     editor->resize(800, 600);
     editor->show();
 
