@@ -5,14 +5,15 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDIT_EMOTICONTEXTEDITSELECTOR_H
-#define KPIMTEXTEDIT_EMOTICONTEXTEDITSELECTOR_H
+#pragma once
 
+#include "kpimtextedit_private_export.h"
 #include <QWidget>
+class QLineEdit;
 namespace KPIMTextEdit
 {
 class EmoticonUnicodeTab;
-class EmoticonTextEditSelector : public QWidget
+class KPIMTEXTEDIT_TESTS_EXPORT EmoticonTextEditSelector : public QWidget
 {
     Q_OBJECT
 public:
@@ -27,8 +28,9 @@ Q_SIGNALS:
 
 private:
     void slotItemSelected(const QString &str);
-    EmoticonUnicodeTab *mUnicodeTab = nullptr;
+    void slotSearchUnicode(const QString &str);
+    EmoticonUnicodeTab *const mUnicodeTab;
+    QLineEdit *const mSearchUnicodeLineEdit;
 };
 }
 
-#endif /* KPIMTEXTEDIT_EMOTICONTEXTEDITSELECTOR_H */
