@@ -4,10 +4,10 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef EMOTICONUNICODEUTILS_H
-#define EMOTICONUNICODEUTILS_H
+#pragma once
 
 #include "kpimtextedit_export.h"
+#include <QObject>
 #include <QString>
 #include <QVector>
 namespace KPIMTextEdit
@@ -15,14 +15,53 @@ namespace KPIMTextEdit
 namespace EmoticonUnicodeUtils
 {
 struct EmoticonStruct {
-    EmoticonStruct(const QString &name, const QString &code)
+    enum EmoticonType {
+        Unknown = 0,
+        FlagsEmoji,
+        FaceEmoji,
+        AnimalsEmoji,
+        PlantEmoji,
+        ScienceEmoji,
+        ComputerEmoji,
+        BookPaperEmoji,
+        SoundMusicEmoji,
+        WeatherEmoji,
+        TimeEmoji,
+        GameEmoji,
+        ClothingEmoji,
+        EventEmoji,
+        FoodEmoji,
+        TransportEmoji,
+        PersonEmoji,
+        PlaceEmoji,
+        SymbolsEmoji,
+        SportEmoji,
+        EmotionEmoji,
+        MoneyEmoji,
+        BodyEmoji,
+        MailEmoji,
+        OfficeEmoji,
+        ToolsEmoji,
+        PhoneEmoji,
+        LockEmoji,
+        DrinkEmoji,
+        VideoEmoji,
+        HouseEmoji,
+        DishwareEmoji,
+        HotelEmoji,
+        AwardMedalEmoji,
+    };
+
+    EmoticonStruct(const QString &name, const QString &code, EmoticonType category)
         : emoticonName(name)
         , emoticonCode(code)
+        , emoticonCategory(category)
     {
     }
 
     QString emoticonName;
     QString emoticonCode;
+    EmoticonType emoticonCategory = EmoticonType::Unknown;
 };
 KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> unicodeFlagsEmoji();
 KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> unicodeFaceEmoji();
@@ -57,7 +96,8 @@ KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> unicodeHouseEmoji(
 KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> unicodeDishwareEmoji();
 KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> unicodeHotelEmoji();
 KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> unicodeAwardMedalEmoji();
+KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QVector<EmoticonStruct> allUnicode();
 }
 }
 
-#endif // EMOTICONUNICODEUTILS_H
+Q_DECLARE_METATYPE(KPIMTextEdit::EmoticonUnicodeUtils::EmoticonStruct::EmoticonType)
