@@ -4,9 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLAINTEXTMARKUPBUILDERTEST_H
-#define PLAINTEXTMARKUPBUILDERTEST_H
-
+#pragma once
 #include <QObject>
 
 class PlainTextMarkupBuilderTest : public QObject
@@ -14,7 +12,7 @@ class PlainTextMarkupBuilderTest : public QObject
     Q_OBJECT
 public:
     explicit PlainTextMarkupBuilderTest(QObject *parent = nullptr);
-    ~PlainTextMarkupBuilderTest() = default;
+    ~PlainTextMarkupBuilderTest() override = default;
 
 private Q_SLOTS:
     void testPlainText();
@@ -48,4 +46,3 @@ private Q_SLOTS:
     void testBrInsideAnchor();
 };
 
-#endif // PLAINTEXTMARKUPBUILDERTEST_H
