@@ -4,9 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEXTHTMLBUILDERTEST_H
-#define TEXTHTMLBUILDERTEST_H
-
+#pragma once
 #include <QObject>
 
 class TextHTMLBuilderTest : public QObject
@@ -14,7 +12,7 @@ class TextHTMLBuilderTest : public QObject
     Q_OBJECT
 public:
     explicit TextHTMLBuilderTest(QObject *parent = nullptr);
-    ~TextHTMLBuilderTest() = default;
+    ~TextHTMLBuilderTest() override = default;
 private Q_SLOTS:
     void testHtmlText_data();
     void testHtmlText();
@@ -51,6 +49,6 @@ private Q_SLOTS:
     void testBug442416();
     void testBug442416Bis();
     void testBugTextColor();
+    void testBugIndent443534();
 };
 
-#endif // TEXTHTMLBUILDERTEST_H
