@@ -4,9 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEXTHTMLBUILDER_H
-#define TEXTHTMLBUILDER_H
-
+#pragma once
 #include "abstractmarkupbuilder.h"
 #include "kpimtextedit_export.h"
 
@@ -130,8 +128,12 @@ public:
     @param leftMargin The new paragraph leftMargin
     @param rightMargin The new paragraph rightMargin
   */
-    void
-    beginParagraph(Qt::Alignment al = Qt::AlignLeft, qreal topMargin = 0.0, qreal bottomMargin = 0.0, qreal leftMargin = 0.0, qreal rightMargin = 0.0) override;
+    void beginParagraph(Qt::Alignment al = Qt::AlignLeft,
+                        qreal topMargin = 0.0,
+                        qreal bottomMargin = 0.0,
+                        qreal leftMargin = 0.0,
+                        qreal rightMargin = 0.0,
+                        bool leftToRightText = false) override;
 
     /**
     Begin a new header element.
@@ -214,4 +216,3 @@ private:
 
 }
 
-#endif // TEXTHTMLBUILDER_H
