@@ -1,21 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "inserthtmleditor.h"
-#include "texteditorcompleter.h"
 #include "kpimtextedit_debug.h"
+#include "texteditorcompleter.h"
 
-#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Theme>
 
-#include <QStringList>
-#include <QCompleter>
 #include <QAbstractItemView>
+#include <QCompleter>
+#include <QStringList>
 
 using namespace KPIMTextEdit;
 
@@ -27,15 +27,14 @@ InsertHtmlEditor::InsertHtmlEditor(QWidget *parent)
         qCWarning(KPIMTEXTEDIT_LOG) << "Invalid definition name";
     }
 
-    auto *hl = new KSyntaxHighlighting::SyntaxHighlighter(document());
-    hl->setTheme((palette().color(QPalette::Base).lightness() < 128)
-                 ? mRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
-                 : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+    auto hl = new KSyntaxHighlighting::SyntaxHighlighter(document());
+    hl->setTheme((palette().color(QPalette::Base).lightness() < 128) ? mRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+                                                                     : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     hl->setDefinition(def);
     setFocus();
     mTextEditorCompleter = new KPIMTextEdit::TextEditorCompleter(this, this);
-    const QStringList completerList = { QStringLiteral("<b></b>"), QStringLiteral("<i></i>"), QStringLiteral("<u></u>")};
-    //Add more
+    const QStringList completerList = {QStringLiteral("<b></b>"), QStringLiteral("<i></i>"), QStringLiteral("<u></u>")};
+    // Add more
     mTextEditorCompleter->setCompleterStringList(completerList);
     mTextEditorCompleter->setExcludeOfCharacters(QStringLiteral("~!@#$%^&*()+{}|,./;'[]\\-= "));
 }
