@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
-#ifndef KPIMTEXTEDIT_INSERTIMAGEWIDGET_H
-#define KPIMTEXTEDIT_INSERTIMAGEWIDGET_H
+#pragma once
 
 #include <QUrl>
 
@@ -38,8 +37,7 @@ Q_SIGNALS:
 
 private:
     friend class InsertImageWidgetPrivate;
-    InsertImageWidgetPrivate *const d;
+    std::unique_ptr<InsertImageWidgetPrivate> const d;
 };
 }
 
-#endif // KPIMTEXTEDIT_INSERTIMAGEWIDGET_H
