@@ -20,7 +20,7 @@ using namespace KPIMTextEdit;
 class InsertTableDialog::InsertTableDialogPrivate
 {
 public:
-    InsertTableDialogPrivate(InsertTableDialog *qq)
+    explicit InsertTableDialogPrivate(InsertTableDialog *qq)
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Insert Table"));
@@ -52,10 +52,7 @@ InsertTableDialog::InsertTableDialog(QWidget *parent)
 {
 }
 
-InsertTableDialog::~InsertTableDialog()
-{
-    delete d;
-}
+InsertTableDialog::~InsertTableDialog() = default;
 
 int InsertTableDialog::columns() const
 {
