@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,9 +10,9 @@
 #include <KLocalizedString>
 #include <QComboBox>
 
-#include <QSpinBox>
-#include <QLabel>
 #include <QGridLayout>
+#include <QLabel>
+#include <QSpinBox>
 
 using namespace KPIMTextEdit;
 
@@ -35,8 +35,8 @@ public:
         mBorder->setValue(1);
         mBorder->setSuffix(i18n(" px"));
 
-        auto *gridLayout = new QGridLayout;
-        gridLayout->setContentsMargins(0, 0, 0, 0);
+        auto gridLayout = new QGridLayout;
+        gridLayout->setContentsMargins({});
         gridLayout->addWidget(new QLabel(i18n("Rows:")), 0, 0);
         gridLayout->addWidget(mRows, 0, 1);
 
@@ -47,7 +47,7 @@ public:
         gridLayout->addWidget(mBorder, 2, 1);
 
         mTypeOfLength = new QComboBox;
-        q->connect(mTypeOfLength, QOverload<int>::of(&QComboBox::activated), q, &InsertTableWidget::slotTypeOfLengthChanged);
+        q->connect(mTypeOfLength, &QComboBox::activated, q, &InsertTableWidget::slotTypeOfLengthChanged);
         // xgettext: no-c-format
         mTypeOfLength->addItem(i18n("% of windows"), QTextLength::PercentageLength);
         mTypeOfLength->addItem(i18n("pixels"), QTextLength::FixedLength);
@@ -77,10 +77,7 @@ InsertTableWidget::InsertTableWidget(QWidget *parent)
 {
 }
 
-InsertTableWidget::~InsertTableWidget()
-{
-    delete d;
-}
+InsertTableWidget::~InsertTableWidget() = default;
 
 void InsertTableWidget::slotTypeOfLengthChanged(int index)
 {
@@ -100,9 +97,7 @@ void InsertTableWidget::slotTypeOfLengthChanged(int index)
 
 QTextLength::Type InsertTableWidget::typeOfLength() const
 {
-    return
-        static_cast<QTextLength::Type>(d->mTypeOfLength->itemData(
-                                           d->mTypeOfLength->currentIndex()).toInt());
+    return static_cast<QTextLength::Type>(d->mTypeOfLength->itemData(d->mTypeOfLength->currentIndex()).toInt());
 }
 
 void InsertTableWidget::setTypeOfLength(QTextLength::Type type)
