@@ -18,7 +18,7 @@ namespace KPIMTextEdit
 class SelectSpecialCharDialogPrivate
 {
 public:
-    SelectSpecialCharDialogPrivate(SelectSpecialCharDialog *qq)
+    explicit SelectSpecialCharDialogPrivate(SelectSpecialCharDialog *qq)
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Select Special Characters"));
@@ -74,7 +74,6 @@ SelectSpecialCharDialog::SelectSpecialCharDialog(QWidget *parent)
 SelectSpecialCharDialog::~SelectSpecialCharDialog()
 {
     writeConfig();
-    delete d;
 }
 
 void SelectSpecialCharDialog::showSelectButton(bool show)
