@@ -1,24 +1,11 @@
 /*
 Gwenview: an image viewer
-Copyright 2007 Aurélien Gâteau <agateau@kde.org>
+SPDX-FileCopyrightText: 2007 Aurélien Gâteau <agateau@kde.org>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+SPDX-License-Identifier: GPL-2.0-or-later
 
 */
-#ifndef SLIDECONTAINER_H
-#define SLIDECONTAINER_H
+#pragma once
 
 // Qt
 #include <QFrame>
@@ -28,7 +15,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 class QPropertyAnimation;
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 /**
  * This widget is design to contain one child widget, the "content" widget.
  * It will start hidden by default. Calling slideIn() will slide in the content
@@ -93,4 +81,3 @@ private:
 };
 } /* namespace */
 
-#endif /* SLIDECONTAINER_H */
