@@ -5,11 +5,10 @@
 
 */
 
-#ifndef KPIMTEXTEDIT_TABLEACTIONMENU_H
-#define KPIMTEXTEDIT_TABLEACTIONMENU_H
+#pragma once
 
 #include <KActionMenu>
-#include <QTextEdit>
+class QTextEdit;
 namespace KPIMTextEdit
 {
 class TableActionMenuPrivate;
@@ -24,9 +23,8 @@ public:
     void setRichTextMode(bool richTextMode);
 
 private:
-    TableActionMenuPrivate *const d;
     friend class TableActionMenuPrivate;
+    std::unique_ptr<TableActionMenuPrivate> const d;
 };
 }
 
-#endif // KPIMTEXTEDIT_TABLEACTIONMENU_H
