@@ -25,7 +25,7 @@ using namespace KPIMTextEdit;
 class TableFormatDialog::TableFormatDialogPrivate
 {
 public:
-    TableFormatDialogPrivate(TableFormatDialog *qq)
+    explicit TableFormatDialogPrivate(TableFormatDialog *qq)
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Table Format"));
@@ -33,7 +33,7 @@ public:
 
         QWidget *page = new QWidget(q);
         auto lay = new QVBoxLayout(page);
-        lay->setContentsMargins(0, 0, 0, 0);
+        lay->setContentsMargins({});
         tableWidget = new InsertTableWidget;
         lay->addWidget(tableWidget);
 
@@ -115,10 +115,7 @@ TableFormatDialog::TableFormatDialog(QWidget *parent)
 {
 }
 
-TableFormatDialog::~TableFormatDialog()
-{
-    delete d;
-}
+TableFormatDialog::~TableFormatDialog() = default;
 
 int TableFormatDialog::columns() const
 {
