@@ -1,33 +1,33 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "texteditfindbarbase.h"
-#include "texteditor/commonwidget/textfindreplacewidget.h"
 #include "kpimtextedit_debug.h"
-#include <QIcon>
-#include <KLocalizedString>
+#include "texteditor/commonwidget/textfindreplacewidget.h"
 #include <KColorScheme>
+#include <KLocalizedString>
+#include <QEvent>
+#include <QHBoxLayout>
+#include <QIcon>
+#include <QKeyEvent>
+#include <QLineEdit>
 #include <QTimer>
 #include <QToolButton>
-#include <QEvent>
-#include <QKeyEvent>
 #include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QLineEdit>
 
 using namespace KPIMTextEdit;
 
 TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
     : QWidget(parent)
 {
-    auto *topLayout = new QVBoxLayout(this);
-    auto *lay = new QHBoxLayout;
+    auto topLayout = new QVBoxLayout(this);
+    auto lay = new QHBoxLayout;
     topLayout->addLayout(lay);
 
-    auto *closeBtn = new QToolButton(this);
+    auto closeBtn = new QToolButton(this);
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setIconSize(QSize(16, 16));
     closeBtn->setToolTip(i18n("Close"));
@@ -133,7 +133,7 @@ void TextEditFindBarBase::autoSearch(const QString &str)
 
 void TextEditFindBarBase::messageInfo(bool backward, bool isAutoSearch, bool found)
 {
-    Q_UNUSED(backward);
+    Q_UNUSED(backward)
     if (!found && !isAutoSearch) {
         QString str = mLastSearchStr;
         if (str.length() > 39) {
@@ -156,7 +156,7 @@ bool TextEditFindBarBase::searchText(bool backward, bool isAutoSearch)
     if (isAutoSearch) {
         autoSearchMoveCursor();
     } else if (mFindWidget->isRegularExpression()) {
-        //TODO
+        // TODO
     } else if (!mLastSearchStr.contains(mFindWidget->searchText(), Qt::CaseSensitive)) {
         clearSelections();
     }
@@ -221,7 +221,7 @@ bool TextEditFindBarBase::event(QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        auto *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             if (shortCutOverride) {
                 e->accept();
@@ -230,8 +230,7 @@ bool TextEditFindBarBase::event(QEvent *e)
             e->accept();
             closeBar();
             return true;
-        } else if (kev->key() == Qt::Key_Enter
-                   || kev->key() == Qt::Key_Return) {
+        } else if (kev->key() == Qt::Key_Enter || kev->key() == Qt::Key_Return) {
             e->accept();
             if (shortCutOverride) {
                 return true;
