@@ -40,10 +40,10 @@ Q_SIGNALS:
     void hideFindBar();
 
 protected:
-    virtual Q_REQUIRED_RESULT bool viewIsReadOnly() const = 0;
-    virtual Q_REQUIRED_RESULT bool documentIsEmpty() const = 0;
-    virtual Q_REQUIRED_RESULT bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) = 0;
-    virtual Q_REQUIRED_RESULT bool searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions) = 0;
+    Q_REQUIRED_RESULT virtual bool viewIsReadOnly() const = 0;
+    Q_REQUIRED_RESULT virtual bool documentIsEmpty() const = 0;
+    Q_REQUIRED_RESULT virtual bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) = 0;
+    Q_REQUIRED_RESULT virtual bool searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions) = 0;
     virtual void autoSearchMoveCursor() = 0;
 
     bool event(QEvent *e) override;
