@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLAINTEXTEDITORTEST_H
-#define PLAINTEXTEDITORTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class PlainTextEditorTest : public QObject
     Q_OBJECT
 public:
     explicit PlainTextEditorTest(QObject *parent = nullptr);
-    ~PlainTextEditorTest();
+    ~PlainTextEditorTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldChangeSpellCheckValue();
 };
 
-#endif // PLAINTEXTEDITORTEST_H
