@@ -87,10 +87,7 @@ PlainTextEditor::PlainTextEditor(QWidget *parent)
     d->mInitialFontSize = font().pointSize();
 }
 
-PlainTextEditor::~PlainTextEditor()
-{
-    delete d;
-}
+PlainTextEditor::~PlainTextEditor() = default;
 
 void PlainTextEditor::addIgnoreWords(const QStringList &lst)
 {
@@ -109,7 +106,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
     if (popup) {
         const bool emptyDocument = document()->isEmpty();
         if (!isReadOnly()) {
-            QList<QAction *> actionList = popup->actions();
+            const QList<QAction *> actionList = popup->actions();
             enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
             QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
@@ -339,7 +336,7 @@ void PlainTextEditor::slotCheckSpelling()
         backgroundSpellCheck->changeLanguage(d->spellCheckingLanguage);
     }
     if (!d->ignoreSpellCheckingWords.isEmpty()) {
-        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
+        for (const QString &word : std::as_const(d->ignoreSpellCheckingWords)) {
             backgroundSpellCheck->speller().addToSession(word);
         }
     }
@@ -747,7 +744,7 @@ void PlainTextEditor::addIgnoreWordsToHighLighter()
     }
     if (d->richTextDecorator) {
         Sonnet::Highlighter *_highlighter = d->richTextDecorator->highlighter();
-        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
+        for (const QString &word : std::as_const(d->ignoreSpellCheckingWords)) {
             _highlighter->ignoreWord(word);
         }
     }
