@@ -41,10 +41,7 @@ PlainTextEditorWidget::PlainTextEditorWidget(QWidget *parent)
     init();
 }
 
-PlainTextEditorWidget::~PlainTextEditorWidget()
-{
-    delete d;
-}
+PlainTextEditorWidget::~PlainTextEditorWidget() = default;
 
 PlainTextEditor *PlainTextEditorWidget::editor() const
 {
@@ -79,7 +76,7 @@ QString PlainTextEditorWidget::toPlainText() const
 void PlainTextEditorWidget::init(PlainTextEditor *customEditor)
 {
     auto lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    lay->setContentsMargins({});
     d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
     if (customEditor) {
