@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "plaintexteditor.h"
 #include "plaintextsyntaxspellcheckinghighlighter.h"
 #include "kpimtextedit_debug.h"
+#include "plaintexteditor.h"
 
 #include <KSyntaxHighlighting/Definition>
 #include <KSyntaxHighlighting/Format>
@@ -19,9 +19,9 @@ Q_DECLARE_METATYPE(QTextBlock)
 
 using namespace KPIMTextEdit;
 
-namespace KPIMTextEdit {
-struct SpellCheckRange
+namespace KPIMTextEdit
 {
+struct SpellCheckRange {
     SpellCheckRange(int o, int l)
         : offset(o)
         , length(l)
@@ -53,13 +53,12 @@ public:
 class PlainTextSyntaxSpellCheckingHighlighterPrivate
 {
 public:
-    PlainTextSyntaxSpellCheckingHighlighterPrivate(PlainTextEditor *plainText)
+    explicit PlainTextSyntaxSpellCheckingHighlighterPrivate(PlainTextEditor *plainText)
         : editor(plainText)
-        , spellCheckingEnabled(false)
     {
     }
 
-    PlainTextEditor *editor = nullptr;
+    PlainTextEditor *const editor;
     QColor misspelledColor;
     bool spellCheckingEnabled = false;
 
@@ -81,10 +80,7 @@ PlainTextSyntaxSpellCheckingHighlighter::PlainTextSyntaxSpellCheckingHighlighter
     setAutomatic(false);
 }
 
-PlainTextSyntaxSpellCheckingHighlighter::~PlainTextSyntaxSpellCheckingHighlighter()
-{
-    delete d;
-}
+PlainTextSyntaxSpellCheckingHighlighter::~PlainTextSyntaxSpellCheckingHighlighter() = default;
 
 void PlainTextSyntaxSpellCheckingHighlighter::toggleSpellHighlighting(bool on)
 {
@@ -131,16 +127,19 @@ void PlainTextSyntaxSpellCheckingHighlighter::highlightBlock(const QString &text
 
     const auto nextBlock = currentBlock().next();
     if (nextBlock.isValid()) {
-        QMetaObject::invokeMethod(this, [this, nextBlock] {
-            rehighlightBlock(nextBlock);
-        }, Qt::QueuedConnection);
+        QMetaObject::invokeMethod(
+            this,
+            [this, nextBlock] {
+                rehighlightBlock(nextBlock);
+            },
+            Qt::QueuedConnection);
     }
 }
 
 void PlainTextSyntaxSpellCheckingHighlighter::unsetMisspelled(int start, int count)
 {
-    Q_UNUSED(start);
-    Q_UNUSED(count);
+    Q_UNUSED(start)
+    Q_UNUSED(count)
 }
 
 void PlainTextSyntaxSpellCheckingHighlighter::setMisspelled(int start, int count)
