@@ -55,7 +55,7 @@ void TextEditorCompleter::TextEditorCompleterPrivate::createCompleter()
     completer->setModelSorting(QCompleter::CaseSensitivelySortedModel);
     completer->setCaseSensitivity(Qt::CaseInsensitive);
     completer->setCompletionMode(QCompleter::PopupCompletion);
-    connect(completer, QOverload<const QString &>::of(&QCompleter::activated), q, &TextEditorCompleter::slotCompletion);
+    connect(completer, qOverload<const QString &>(&QCompleter::activated), q, &TextEditorCompleter::slotCompletion);
 }
 
 QString TextEditorCompleter::TextEditorCompleterPrivate::wordUnderCursor() const
@@ -139,10 +139,7 @@ TextEditorCompleter::TextEditorCompleter(QPlainTextEdit *editor, QObject *parent
 {
 }
 
-TextEditorCompleter::~TextEditorCompleter()
-{
-    delete d;
-}
+TextEditorCompleter::~TextEditorCompleter() = default;
 
 QCompleter *TextEditorCompleter::completer() const
 {
