@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,18 +22,18 @@ bool AbstractTextToSpeechInterface::isReady() const
 
 void AbstractTextToSpeechInterface::say(const QString &text)
 {
-    Q_UNUSED(text);
+    Q_UNUSED(text)
 }
 
 int AbstractTextToSpeechInterface::volume() const
 {
-    //TODO add default value ? 0 ?
+    // TODO add default value ? 0 ?
     return 50;
 }
 
 void AbstractTextToSpeechInterface::setVolume(int value)
 {
-    Q_UNUSED(value);
+    Q_UNUSED(value)
 }
 
 void AbstractTextToSpeechInterface::reloadSettings()
