@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "texttospeech/texttospeechconfigdialog.h"
 #include "texttospeech/texttospeech.h"
+#include "texttospeech/texttospeechconfigdialog.h"
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
@@ -19,7 +19,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new KPIMTextEdit::TextToSpeechConfigDialog;
+    auto w = new KPIMTextEdit::TextToSpeechConfigDialog;
 
     w->show();
     app.exec();
