@@ -12,6 +12,6 @@ class TextToSpeechConfigGui : public QWidget
     Q_OBJECT
 public:
     explicit TextToSpeechConfigGui(QWidget *parent = nullptr);
-    ~TextToSpeechConfigGui();
+    ~TextToSpeechConfigGui() override;
 };
 
