@@ -46,6 +46,6 @@ private:
     void slotVolumeChanged(int value);
     void slotCloseTextToSpeechWidget();
     void slotConfigure();
-    TextToSpeechWidgetPrivate *const d;
+    std::unique_ptr<TextToSpeechWidgetPrivate> const d;
 };
 }
