@@ -4,9 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTGENERATEHTMLBUILDERGUI_H
-#define TESTGENERATEHTMLBUILDERGUI_H
-
+#pragma once
 #include <QWidget>
 
 class TestGenerateHTMLBuilderGui : public QWidget
@@ -14,7 +12,6 @@ class TestGenerateHTMLBuilderGui : public QWidget
     Q_OBJECT
 public:
     explicit TestGenerateHTMLBuilderGui(QWidget *parent = nullptr);
-    ~TestGenerateHTMLBuilderGui();
+    ~TestGenerateHTMLBuilderGui() override;
 };
 
-#endif // TESTGENERATEHTMLBUILDERGUI_H
