@@ -4,9 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TestGeneratePlainTextBuilderGui_H
-#define TestGeneratePlainTextBuilderGui_H
-
+#pragma once
 #include <QWidget>
 
 class TestGeneratePlainTextBuilderGui : public QWidget
@@ -14,7 +12,6 @@ class TestGeneratePlainTextBuilderGui : public QWidget
     Q_OBJECT
 public:
     explicit TestGeneratePlainTextBuilderGui(QWidget *parent = nullptr);
-    ~TestGeneratePlainTextBuilderGui();
+    ~TestGeneratePlainTextBuilderGui() override;
 };
 
-#endif // TestGeneratePlainTextBuilderGui_H
